Why is Karma named Karma? - My site
Description: Is there a specific reason why Karma is named Karma and not Reputation? Just asking, I assume it won't be a big deal to change in a local installation.
Keywords: ,Askbot,forum,community

First time here? Check out the FAQ!

Hi there! Please sign in help
English ▼
tags users badges

| ALL UNANSWERED |  | Ask Your Question

8

# Why is Karma named Karma?

- karma
- reputation
- naming-conventions

asked 2010-04-23 15:02:11 -0600

Pekka
600 ●22 ●28 ●37

Is there a specific reason why Karma is named Karma and not Reputation? Just asking, I assume it won't be a big deal to change in a local installation.

edit retag flag offensive close merge delete

## Comments

I want to +1 this for being a good question, but if I +1 it, @Evgeny might interpret that as a vote to change the text to 'reputation'! I like being distinct from that certain other group of Q&A-based websites... (:

todofixthis ( 2012-05-17 16:30:01 -0600 )edit
add a comment

## 1 answer

Sort by » oldest newest most voted
2

answered 2010-04-24 12:53:32 -0600

Evgeny
14023 ●56 ●98 ●212 http://askbot.org/

updated 2010-04-24 17:11:10 -0600

Sure, some people will like reputation, others will like karma. If your post gets many upvotes we'll change "karma" to "reputation". So whoever likes word "reputation" better - please vote for Pekka's question!

This post explains how to change messages in the main localization file (there is also a small javascript language file `forum/skins/default/media/js/com.cnprog.i18n.js`). There are nine messages containing word karma in the locale file and one more in `.js` file.

edit flag offensive delete link more

## Comments

1
I am fine with Karma really but askbot is using it inconsistently. The user profile page for instance has a link called reputation instead. You should use karma there as well and in the url too
mether ( 2011-07-15 22:37:54 -0600 )edit
add a comment

## Your Answer

Please start posting anonymously - your entry will be published after you log in or create a new account.

Add Answer

[hide preview]
community wiki (karma is not awarded & many others can edit wiki post)

## Question Tools

2 followers

## Stats

Asked: 2010-04-23 15:02:11 -0600

Seen: 1,286 times

Last updated: Apr 24 '10

## Related questions

Determine expert users not only with generic Karma for all

Can I remove the word "Karma" and use instead the word "Reputation"?

Where can I find the list of karma thresholds for various actions/privileges?

How to increase user's karma?

Custom reputation e.g. karma, badges

Extracting the karma/reputation system into its own pluggable app

FAQ's karma list generated automatically

How to rename Karma to something else using django-rosetta?

Include descriptions in karma change log

live settings about downvoting karma loss

Copyright Askbot, 2010-2011. Content on this site is licensed under a Creative Commons Attribution Share Alike 3.0 license.
Powered by Askbot version 0.7.54
( 2016-11-07 08:59:45 -0600 )edit
none